// Convergence model

var Y C IN G K A Q R B CA;
varexo A0 B0 K0;

parameters gamma alpha delta ro phi psi Rstar Qstar GYrat IKrat IYrat;
// growth rate
gamma = 0.015;
// capital share
alpha = 0.30;
// depreciation rate
delta = 0.08;
// convergence pace
ro = 0.95;
// cost of adjustmnet
phi = 0.50;
// risk premium coefficient
psi = 0.0015;
// external real interest rate
Rstar = 1.04;
// Tobin's Q in steady state
Qstar = 1/(1-phi);
// government spending-output ratio
GYrat = 0.20;
// investrment-capital ratio
IKrat = 2*(delta+gamma)/(2-phi);
// investment-output ratio
IYrat = IKrat / (Qstar/alpha*(Rstar + delta - 1 - phi/2*IKrat));
// output-capital ratio
// YKrat = Qstar/alpha*(Rstar + delta - 1 - phi/2*IKrat);

model;
// Euler condition (1)
C(+1) = C*R(+1);
// interest rate (2)
R = exp(-psi*(B(-1)+ B0));
// net foreign assets accumulation (3)
B = (Rstar/(1+gamma))*R*(B(-1)+B0) + Y - (1-IYrat-GYrat)*C - IYrat*IN - GYrat*G;
// output dynamics (4)
Y = A*(K(-1)+K0)^alpha;
// capital accumulation (5)
(1+gamma)*K = (1-delta)*(K(-1)+K0) + IKrat*IN*(1-phi/2*IN/(K(-1)+K0));
// productivity convergence (6)
A = ro*(A(-1)+A0) + (1-ro);
// government spending (7)
G = Y;
// current account (8)
CA = B - (B(-1)+B0)/(1+gamma);
// q-Tobin - investment equation (9)
1/(Q*Qstar) = 1 - phi*IN/(K(-1)+K0);
// law of motion for Tobin's q (10)
Q*R(+1)*Rstar = A(+1)*K^(alpha-1)*(Rstar+delta-1-phi/2*IKrat) + Q(+1)*(1-delta+phi/2*IKrat*(IN(+1)/K)^2);
end;

initval;
Y = 1;
C = 1;
IN = 1; 
G = 1;
K = 1;
A = 1;
Q = 1;
R = 1;
B = 0;
CA = 0;
end;

steady;

check;

shocks;
var K0;
periods 1;
values -0.058567746;
var B0;
periods 1;
values -0.03459604;
var A0;
periods 1;
values -0.039769229; 
end;				
	
		
		  	
simul(periods=500);

//rplot y c in;
//rplot b ca;
//rplot k q;






